@@ -3,4 +3,4 @@
 import sys
 
 
-WIN = sys.platform in ('win32', 'cygwin')
+WIN = sys.platform in ("win32", "cygwin")
