@@ -1,4 +1,5 @@
 from copy import copy
+from importlib import resources
 from io import BytesIO, TextIOWrapper
 import logging
 import os
@@ -10,17 +11,6 @@ from typing import Union, IO
 from configobj import ConfigObj, ConfigObjError
 import pyaes
 
-try:
-    import importlib.resources as resources
-except ImportError:
-    # Python < 3.7
-    import importlib_resources as resources
-
-try:
-    basestring
-except NameError:
-    basestring = str
-
 
 logger = logging.getLogger(__name__)
 
@@ -45,17 +35,17 @@ def read_config_file(f, list_values=True):
 
     """
 
-    if isinstance(f, basestring):
+    if isinstance(f, str):
         f = os.path.expanduser(f)
 
     try:
         config = ConfigObj(f, interpolation=False, encoding="utf8", list_values=list_values)
     except ConfigObjError as e:
-        log(logger, logging.WARNING, "Unable to parse line {0} of config file " "'{1}'.".format(e.line_number, f))
+        log(logger, logging.WARNING, "Unable to parse line {0} of config file '{1}'.".format(e.line_number, f))
         log(logger, logging.WARNING, "Using successfully parsed config values.")
         return e.config
     except (IOError, OSError) as e:
-        log(logger, logging.WARNING, "You don't have permission to read " "config file '{0}'.".format(e.filename))
+        log(logger, logging.WARNING, "You don't have permission to read config file '{0}'.".format(e.filename))
         return None
 
     return config
@@ -78,12 +68,12 @@ def get_included_configs(config_file: Union[str, TextIOWrapper]) -> list:
     try:
         with open(config_file) as f:
             include_directives = filter(lambda s: s.startswith("!includedir"), f)
-            dirs = map(lambda s: s.strip().split()[-1], include_directives)
-            dirs = filter(os.path.isdir, dirs)
-            for dir in dirs:
-                for filename in os.listdir(dir):
+            dirs_split = (s.strip().split()[-1] for s in include_directives)
+            dirs = filter(os.path.isdir, dirs_split)
+            for dir_ in dirs:
+                for filename in os.listdir(dir_):
                     if filename.endswith(".cnf"):
-                        included_configs.append(os.path.join(dir, filename))
+                        included_configs.append(os.path.join(dir_, filename))
     except (PermissionError, UnicodeDecodeError):
         pass
     return included_configs
@@ -289,7 +279,7 @@ def str_to_bool(s):
     """Convert a string value to its corresponding boolean value."""
     if isinstance(s, bool):
         return s
-    elif not isinstance(s, basestring):
+    elif not isinstance(s, str):
         raise TypeError("argument must be a string")
 
     true_values = ("true", "on", "1")
@@ -310,7 +300,7 @@ def strip_matching_quotes(s):
     values.
 
     """
-    if isinstance(s, basestring) and len(s) >= 2 and s[0] == s[-1] and s[0] in ('"', "'"):
+    if isinstance(s, str) and len(s) >= 2 and s[0] == s[-1] and s[0] in ('"', "'"):
         s = s[1:-1]
     return s
 
