@@ -1,5 +1,4 @@
 from collections import defaultdict
-from io import open
 import os
 import sys
 import shutil
@@ -7,7 +6,6 @@ import traceback
 import logging
 import threading
 import re
-import stat
 from collections import namedtuple
 
 try:
@@ -60,18 +58,10 @@ import itertools
 
 click.disable_unicode_literals_warning = True
 
-try:
-    from urlparse import urlparse
-    from urlparse import unquote
-except ImportError:
-    from urllib.parse import urlparse
-    from urllib.parse import unquote
+from urllib.parse import urlparse
+from urllib.parse import unquote
 
-try:
-    import importlib.resources as resources
-except ImportError:
-    # Python < 3.7
-    import importlib_resources as resources
+from importlib import resources
 
 try:
     import paramiko
@@ -81,7 +71,11 @@ except ImportError:
 # Query tuples are used for maintaining history
 Query = namedtuple("Query", ["query", "successful", "mutating"])
 
-SUPPORT_INFO = "Home: http://mycli.net\n" "Bug tracker: https://github.com/dbcli/mycli/issues"
+SUPPORT_INFO = "Home: http://mycli.net\nBug tracker: https://github.com/dbcli/mycli/issues"
+
+
+class PasswordFileError(Exception):
+    """Base exception for errors related to reading password files."""
 
 
 class MyCli(object):
@@ -99,10 +93,7 @@ class MyCli(object):
     ]
 
     # check XDG_CONFIG_HOME exists and not an empty string
-    if os.environ.get("XDG_CONFIG_HOME"):
-        xdg_config_home = os.environ.get("XDG_CONFIG_HOME")
-    else:
-        xdg_config_home = "~/.config"
+    xdg_config_home = os.environ.get("XDG_CONFIG_HOME", "~/.config")
     system_config_files = ["/etc/myclirc", os.path.join(os.path.expanduser(xdg_config_home), "mycli", "myclirc")]
 
     pwd_config_file = os.path.join(os.getcwd(), ".myclirc")
@@ -251,7 +242,7 @@ class MyCli(object):
             arg = re.sub(r"``", r"`", arg)
         self.sqlexecute.change_db(arg)
 
-        yield (None, None, None, 'You are now connected to database "%s" as ' 'user "%s"' % (self.sqlexecute.dbname, self.sqlexecute.user))
+        yield (None, None, None, 'You are now connected to database "%s" as user "%s"' % (self.sqlexecute.dbname, self.sqlexecute.user))
 
     def execute_from_file(self, arg, **_):
         if not arg:
@@ -303,7 +294,7 @@ class MyCli(object):
             self.echo('Error: Unable to open the log file "{}".'.format(log_file), err=True, fg="red")
             return
 
-        formatter = logging.Formatter("%(asctime)s (%(process)d/%(threadName)s) " "%(name)s %(levelname)s - %(message)s")
+        formatter = logging.Formatter("%(asctime)s (%(process)d/%(threadName)s) %(name)s %(levelname)s - %(message)s")
 
         handler.setFormatter(formatter)
 
@@ -524,24 +515,29 @@ class MyCli(object):
                     port = int(port)
                 except ValueError:
                     self.echo("Error: Invalid port number: '{0}'.".format(port), err=True, fg="red")
-                    exit(1)
+                    sys.exit(1)
 
                 _connect()
         except Exception as e:  # Connecting to a database could fail.
             self.logger.debug("Database connection failed: %r.", e)
             self.logger.error("traceback: %r", traceback.format_exc())
             self.echo(str(e), err=True, fg="red")
-            exit(1)
+            sys.exit(1)
 
     def get_password_from_file(self, password_file):
-        password_from_file = None
         if password_file:
-            if (os.path.isfile(password_file) or stat.S_ISFIFO(os.stat(password_file).st_mode)) and os.access(password_file, os.R_OK):
+            try:
                 with open(password_file) as fp:
-                    password_from_file = fp.readline()
-                    password_from_file = password_from_file.rstrip().lstrip()
-
-        return password_from_file
+                    password = fp.readline().strip()
+                    return password
+            except FileNotFoundError:
+                raise PasswordFileError(f"Password file '{password_file}' not found") from None
+            except PermissionError:
+                raise PasswordFileError(f"Permission denied reading password file '{password_file}'") from None
+            except IsADirectoryError:
+                raise PasswordFileError(f"Path '{password_file}' is a directory, not a file") from None
+            except Exception as e:
+                raise PasswordFileError(f"Error reading password file '{password_file}': {str(e)}") from None
 
     def handle_editor_command(self, text):
         r"""Editor command is any query that is prefixed or suffixed by a '\e'.
@@ -633,7 +629,7 @@ class MyCli(object):
         else:
             history = None
             self.echo(
-                'Error: Unable to open the history file "{}". ' "Your query history will not be saved.".format(history_file),
+                'Error: Unable to open the history file "{}". Your query history will not be saved.'.format(history_file),
                 err=True,
                 fg="red",
             )
@@ -674,6 +670,7 @@ class MyCli(object):
                     return
 
                 special.set_expanded_output(False)
+                special.set_forced_horizontal_output(False)
 
                 try:
                     text = self.handle_editor_command(text)
@@ -743,6 +740,9 @@ class MyCli(object):
                     else:
                         max_width = None
 
+                    if special.forced_horizontal():
+                        max_width = None
+
                     formatted = self.format_output(title, cur, headers, special.is_expanded_output(), max_width)
 
                     t = time() - start
@@ -1099,7 +1099,7 @@ class MyCli(object):
 
 @click.command()
 @click.option("-h", "--host", envvar="MYSQL_HOST", help="Host address of the database.")
-@click.option("-P", "--port", envvar="MYSQL_TCP_PORT", type=int, help="Port number to use for connection. Honors " "$MYSQL_TCP_PORT.")
+@click.option("-P", "--port", envvar="MYSQL_TCP_PORT", type=int, help="Port number to use for connection. Honors $MYSQL_TCP_PORT.")
 @click.option("-u", "--user", help="User name to connect to the database.")
 @click.option("-S", "--socket", envvar="MYSQL_UNIX_PORT", help="The socket file to use for connection.")
 @click.option("-p", "--password", "password", envvar="MYSQL_PWD", type=str, help="Password to connect to the database.")
@@ -1125,7 +1125,7 @@ class MyCli(object):
 @click.option(
     "--ssl-verify-server-cert",
     is_flag=True,
-    help=('Verify server\'s "Common Name" in its cert against ' "hostname used when connecting. This option is disabled " "by default."),
+    help=('Verify server\'s "Common Name" in its cert against hostname used when connecting. This option is disabled by default.'),
 )
 # as of 2016-02-15 revocation list is not supported by underling PyMySQL
 # library (--ssl-crl and --ssl-crlpath options in vanilla mysql client)
@@ -1223,11 +1223,11 @@ def cli(
         try:
             alias_dsn = mycli.config["alias_dsn"]
         except KeyError:
-            click.secho("Invalid DSNs found in the config file. " 'Please check the "[alias_dsn]" section in myclirc.', err=True, fg="red")
-            exit(1)
+            click.secho("Invalid DSNs found in the config file. Please check the \"[alias_dsn]\" section in myclirc.", err=True, fg="red")
+            sys.exit(1)
         except Exception as e:
             click.secho(str(e), err=True, fg="red")
-            exit(1)
+            sys.exit(1)
         for alias, value in alias_dsn.items():
             if verbose:
                 click.secho("{} : {}".format(alias, value))
@@ -1262,9 +1262,13 @@ def cli(
 
     dsn_uri = None
 
-    # Treat the database argument as a DSN alias if we're missing
-    # other connection information.
-    if mycli.config["alias_dsn"] and database and "://" not in database and not any([user, password, host, port, login_path]):
+    # Treat the database argument as a DSN alias only if it matches a configured alias
+    if (
+        database
+        and "://" not in database
+        and not any([user, password, host, port, login_path])
+        and database in mycli.config.get("alias_dsn", {})
+    ):
         dsn, database = database, ""
 
     if database and "://" in database:
@@ -1275,11 +1279,11 @@ def cli(
             dsn_uri = mycli.config["alias_dsn"][dsn]
         except KeyError:
             click.secho(
-                "Could not find the specified DSN in the config file. " 'Please check the "[alias_dsn]" section in your ' "myclirc.",
+                "Could not find the specified DSN in the config file. Please check the \"[alias_dsn]\" section in your myclirc.",
                 err=True,
                 fg="red",
             )
-            exit(1)
+            sys.exit(1)
         else:
             mycli.dsn_alias = dsn
 
@@ -1306,6 +1310,29 @@ def cli(
         ssh_key_filename = ssh_key_filename if ssh_key_filename else ssh_config.get("identityfile", [None])[0]
 
     ssh_key_filename = ssh_key_filename and os.path.expanduser(ssh_key_filename)
+    # Merge init-commands: global, DSN-specific, then CLI
+    init_cmds = []
+    # 1) Global init-commands
+    global_section = mycli.config.get("init-commands", {})
+    for _, val in global_section.items():
+        if isinstance(val, (list, tuple)):
+            init_cmds.extend(val)
+        elif val:
+            init_cmds.append(val)
+    # 2) DSN-specific init-commands
+    if dsn:
+        alias_section = mycli.config.get("alias_dsn.init-commands", {})
+        if dsn in alias_section:
+            val = alias_section.get(dsn)
+            if isinstance(val, (list, tuple)):
+                init_cmds.extend(val)
+            elif val:
+                init_cmds.append(val)
+    # 3) CLI-provided init_command
+    if init_command:
+        init_cmds.append(init_command)
+
+    combined_init_cmd = "; ".join(cmd.strip() for cmd in init_cmds if cmd)
 
     mycli.connect(
         database=database,
@@ -1321,12 +1348,15 @@ def cli(
         ssh_port=ssh_port,
         ssh_password=ssh_password,
         ssh_key_filename=ssh_key_filename,
-        init_command=init_command,
+        init_command=combined_init_cmd,
         charset=charset,
         password_file=password_file,
     )
 
-    mycli.logger.debug("Launch Params: \n" "\tdatabase: %r" "\tuser: %r" "\thost: %r" "\tport: %r", database, user, host, port)
+    if combined_init_cmd:
+        click.echo("Executing init-command: %s" % combined_init_cmd, err=True)
+
+    mycli.logger.debug("Launch Params: \n\tdatabase: %r\tuser: %r\thost: %r\tport: %r", database, user, host, port)
 
     #  --execute argument
     if execute:
@@ -1342,10 +1372,10 @@ def cli(
                 mycli.formatter.format_name = "tsv"
 
             mycli.run_query(execute)
-            exit(0)
+            sys.exit(0)
         except Exception as e:
             click.secho(str(e), err=True, fg="red")
-            exit(1)
+            sys.exit(1)
 
     if sys.stdin.isatty():
         mycli.run_cli()
@@ -1357,7 +1387,7 @@ def cli(
             click.secho("Failed! Ran out of memory.", err=True, fg="red")
             click.secho("You might want to try the official mysql client.", err=True, fg="red")
             click.secho("Sorry... :(", err=True, fg="red")
-            exit(1)
+            sys.exit(1)
 
         if mycli.destructive_warning and is_destructive(stdin_text):
             try:
@@ -1366,7 +1396,7 @@ def cli(
             except (IOError, OSError):
                 mycli.logger.warning("Unable to open TTY as stdin.")
             if not warn_confirmed:
-                exit(0)
+                sys.exit(0)
 
         try:
             new_line = True
@@ -1377,10 +1407,10 @@ def cli(
                 mycli.formatter.format_name = "tsv"
 
             mycli.run_query(stdin_text, new_line=new_line)
-            exit(0)
+            sys.exit(0)
         except Exception as e:
             click.secho(str(e), err=True, fg="red")
-            exit(1)
+            sys.exit(1)
 
 
 def need_completion_refresh(queries):
@@ -1414,7 +1444,7 @@ def is_mutating(status):
     if not status:
         return False
 
-    mutating = set(["insert", "update", "delete", "alter", "create", "drop", "replace", "truncate", "load", "rename"])
+    mutating = {"insert", "update", "delete", "alter", "create", "drop", "replace", "truncate", "load", "rename"}
     return status.split(None, 1)[0].lower() in mutating
 
 
