@@ -4,7 +4,6 @@ import locale
 import logging
 import subprocess
 import shlex
-from io import open
 from time import sleep
 
 import click
@@ -20,6 +19,7 @@ from mycli.packages.prompt_utils import confirm_destructive_query
 
 TIMING_ENABLED = False
 use_expanded_output = False
+force_horizontal_output = False
 PAGER_ENABLED = True
 tee_file = None
 once_file = None
@@ -98,6 +98,17 @@ def is_expanded_output():
     return use_expanded_output
 
 
+@export
+def set_forced_horizontal_output(val):
+    global force_horizontal_output
+    force_horizontal_output = val
+
+
+@export
+def forced_horizontal():
+    return force_horizontal_output
+
+
 _logger = logging.getLogger(__name__)
 
 
@@ -535,6 +546,6 @@ def get_current_delimiter():
 
 
 @export
-def split_queries(input):
-    for query in delimiter_command.queries_iter(input):
+def split_queries(input_str):
+    for query in delimiter_command.queries_iter(input_str):
         yield query
