@@ -195,14 +195,12 @@ class SQLExecute(object):
             init_command,
         )
         conv = conversions.copy()
-        conv.update(
-            {
-                FIELD_TYPE.TIMESTAMP: lambda obj: (convert_datetime(obj) or obj),
-                FIELD_TYPE.DATETIME: lambda obj: (convert_datetime(obj) or obj),
-                FIELD_TYPE.TIME: lambda obj: (convert_timedelta(obj) or obj),
-                FIELD_TYPE.DATE: lambda obj: (convert_date(obj) or obj),
-            }
-        )
+        conv.update({
+            FIELD_TYPE.TIMESTAMP: lambda obj: (convert_datetime(obj) or obj),
+            FIELD_TYPE.DATETIME: lambda obj: (convert_datetime(obj) or obj),
+            FIELD_TYPE.TIME: lambda obj: (convert_timedelta(obj) or obj),
+            FIELD_TYPE.DATE: lambda obj: (convert_date(obj) or obj),
+        })
 
         defer_connect = False
 
@@ -233,7 +231,7 @@ class SQLExecute(object):
             ssl=ssl_context,
             program_name="mycli",
             defer_connect=defer_connect,
-            init_command=init_command,
+            init_command=init_command or None,
         )
 
         if ssh_host:
@@ -298,6 +296,12 @@ class SQLExecute(object):
             if sql.endswith("\\G"):
                 special.set_expanded_output(True)
                 sql = sql[:-2].strip()
+            # \g is treated specially since we might want collapsed output when
+            # auto vertical output is enabled
+            elif sql.endswith('\\g'):
+                special.set_expanded_output(False)
+                special.set_forced_horizontal_output(True)
+                sql = sql[:-2].strip()
 
             cur = self.conn.cursor()
             try:  # Special command
