@@ -44,7 +44,7 @@ def test_bools(executor):
 @dbtest
 def test_binary(executor):
     run(executor, """create table bt(geom linestring NOT NULL)""")
-    run(executor, "INSERT INTO bt VALUES " "(ST_GeomFromText('LINESTRING(116.37604 39.73979,116.375 39.73965)'));")
+    run(executor, "INSERT INTO bt VALUES (ST_GeomFromText('LINESTRING(116.37604 39.73979,116.375 39.73965)'));")
     results = run(executor, """select * from bt""")
 
     geom = (
@@ -61,8 +61,8 @@ def test_table_and_columns_query(executor):
     run(executor, "create table a(x text, y text)")
     run(executor, "create table b(z text)")
 
-    assert set(executor.tables()) == set([("a",), ("b",)])
-    assert set(executor.table_columns()) == set([("a", "x"), ("a", "y"), ("b", "z")])
+    assert set(executor.tables()) == {("a",), ("b",)}
+    assert set(executor.table_columns()) == {("a", "x"), ("a", "y"), ("b", "z")}
 
 
 @dbtest
@@ -139,7 +139,7 @@ def test_favorite_query_multiple_statement(executor):
     run(executor, "insert into test values('abc')")
     run(executor, "insert into test values('def')")
 
-    results = run(executor, "\\fs test-ad select * from test where a like 'a%'; " "select * from test where a like 'd%'")
+    results = run(executor, "\\fs test-ad select * from test where a like 'a%'; select * from test where a like 'd%'")
     assert_result_equal(results, status="Saved.")
 
     results = run(executor, "\\f test-ad")
@@ -173,6 +173,13 @@ def test_favorite_query_expanded_output(executor):
     assert_result_equal(results, status="test-ae: Deleted")
 
 
+@dbtest
+def test_collapsed_output_special_command(executor):
+    set_expanded_output(True)
+    run(executor, "select 1\\g")
+    assert is_expanded_output() is False
+
+
 @dbtest
 def test_special_command(executor):
     results = run(executor, "\\?")
